@@ -542,6 +542,7 @@ sub conditionSub {
     if ( $cond =~ /^logout_app(?:\s+(.*))?$/i ) {
         return $class->logout_app($1);
     }
+
     # logout_app_sso
     elsif ( $cond =~ /^logout_app_sso(?:\s+(.*))?$/i ) {
         return $class->logout_app_sso($1);
@@ -562,6 +563,15 @@ sub conditionSub {
     return ( $sub, $mayskip );
 }
 
+## These methods should be overriden in subclasses
+sub logout_app {
+    return ( sub { 1 }, 0 );
+}
+
+sub logout_app_sso {
+    return ( sub { 1 }, 0 );
+}
+
 ## @method arrayref aliasInit
 # @param options vhostOptions configuration item
 # @return arrayref of vhost and aliases
